using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;

namespace Vevo.Base.Domain
{
    public class EntityList<T> : IEntityList<T>
    {
        #region Private

        private IList<T> _list = new List<T>();

        private IList<T> _addedList = new List<T>();
        private IList<T> _removedList = new List<T>();


        private void UpdateRemove( T item )
        {
            if (_addedList.Contains( item ))
                _addedList.Remove( item );
            else
                _removedList.Add( item );
        }
        #endregion


        #region Constructors

        public EntityList()
        {
        }

        public EntityList( IList<T> list )
        {
            _list = list;
        }

        #endregion


        #region IEntityList<T> Members

        public IList<T> GetAddedList()
        {
            return _addedList;
        }

        public IList<T> GetUpdatedList()
        {
            List<T> updatedList = new List<T>();

            foreach (T item in _list)
            {
                if (!_addedList.Contains( item ))
                    updatedList.Add( item );
            }

            return updatedList;
        }

        public IList<T> GetRemovedList()
        {
            return _removedList;
        }

        public void AcceptChanges()
        {
            _addedList.Clear();
            _removedList.Clear();
        }

        public IEntityList<T> Clone()
        {
            EntityList<T> newList = new EntityList<T>();

            foreach (T item in this)
            {
                //if (item is ICloneable)
                //    newList.Add( ((ICloneable) item).Clone );
                //else
                newList.Add( item );
            }

            return newList;
        }

        #endregion


        #region IList<T> Members

        public int IndexOf( T item )
        {
            return _list.IndexOf( item );
        }

        public void Insert( int index, T item )
        {
            _list.Insert( index, item );
            _addedList.Add( item );
        }

        public void RemoveAt( int index )
        {
            UpdateRemove( _list[index] );
            _list.RemoveAt( index );
        }

        public T this[int index]
        {
            get
            {
                return _list[index];
            }
            set
            {
                _list[index] = value;
            }
        }

        #endregion


        #region ICollection<T> Members

        public void Add( T item )
        {
            _list.Add( item );
            _addedList.Add( item );
        }

        public void Clear()
        {
            // Items in normal list will be moved to removed list.
            for (int i = _list.Count - 1; i >= 0; i--)
                RemoveAt( i );

            _addedList.Clear();
        }

        public bool Contains( T item )
        {
            return _list.Contains( item );
        }

        public void CopyTo( T[] array, int arrayIndex )
        {
            _list.CopyTo( array, arrayIndex );
        }

        public int Count
        {
            get { return _list.Count; }
        }

        public bool IsReadOnly
        {
            get { return _list.IsReadOnly; }
        }

        public bool Remove( T item )
        {
            UpdateRemove( item );
            return _list.Remove( item );
        }

        #endregion


        #region IEnumerable<T> Members

        public IEnumerator<T> GetEnumerator()
        {
            return _list.GetEnumerator();
        }

        #endregion


        #region IEnumerable Members

        IEnumerator IEnumerable.GetEnumerator()
        {
            return ((IEnumerable) _list).GetEnumerator();
        }

        #endregion
    }

}
