using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Users;
using Vevo.Shared.Utilities;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class AdminRepository : IAdminRepository
    {
        #region Private

        private const string RepositoryName = "AdminRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetIDFromUserNameSignature = "GetIDFromUserName";
        private const string SearchAdminSignature = "SearchAdmin";
        private const string GetTableSchemaSignature = "GetTableSchema";
        private const string TableName = "Admin";

        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );

        private AdminRepositoryNoCache _repository = new AdminRepositoryNoCache();

        #endregion

        #region Constructors

        public AdminRepository()
        {
        }

        public AdminRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public Admin Save( Admin admin )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            Admin newAdmin = _repository.Save( admin );
            _dataCache.ClearRepositoryCache();
            return newAdmin;
        }

        public Admin GetOne( string adminID )
        {
            Admin result = (Admin) _dataCache.GetValue( GetOneSignature, _cacheDependency, adminID );

            if (result == null)
            {
                result = _repository.GetOne( adminID );
                _dataCache.SetValue( GetOneSignature, result, adminID );
            }

            return result;
        }

        public string GetIDFromUserName( string userName )
        {
            object result = _dataCache.GetValue( GetIDFromUserNameSignature, _cacheDependency, userName );

            if (result == null)
            {
                result = _repository.GetIDFromUserName( userName );
                _dataCache.SetValue( GetIDFromUserNameSignature, result, userName );
            }

            return ConvertUtilities.ToString( result );
        }

        public void Delete( string adminID )
        {
            _repository.Delete( adminID );
            _dataCache.ClearRepositoryCache();
        }

        public IList<Admin> SearchAdmin(
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            howManyItems = 0;
            Pair result = (Pair) _dataCache.GetValue(
                SearchAdminSignature,
                _cacheDependency, 
                sortBy,
                searchFilter.ToString(),
                startIndex,
                endIndex
                );

            if (result == null)
            {
                result = new Pair();
                result.First = _repository.SearchAdmin(
                    sortBy, searchFilter, startIndex, endIndex, out howManyItems );
                result.Second = howManyItems;
                _dataCache.SetValue(
                    SearchAdminSignature,
                    result,
                    sortBy,
                    searchFilter.ToString(),
                    startIndex,
                    endIndex );
            }

            howManyItems = ConvertUtilities.ToInt32( result.Second );
            return (IList<Admin>) result.First;
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            IList<TableSchemaItem> list = (IList<TableSchemaItem>) _dataCache.GetValue(
                    GetTableSchemaSignature, _cacheDependency
                    );

            if (list == null)
            {
                list = _repository.GetTableSchema();
                _dataCache.SetValue(
                    GetTableSchemaSignature,
                    list
                    );
            }

            return list;
        }

        #endregion
    }
}
