using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using Vevo.DataAccessLib;

namespace Vevo.Data.DataUtilities
{
    public static class DateUtilities
    {
        public static string CreateFromDateNoAnd(
            DateTime? from,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (from == null)
                return String.Empty;

            DateTime from12am = new DateTime( from.Value.Year, from.Value.Month, from.Value.Day, 0, 0, 0 );
            parameters.Add( DataAccess.CreateParameterDateTime( from12am ) );
            return String.Format( " {0} >= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateFromDateFor24HoursNoAnd(
            DateTime? from,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (from == null)
                return String.Empty;

            DateTime fromDate = new DateTime( from.Value.Year, from.Value.Month, from.Value.Day,
                from.Value.Hour, from.Value.Minute, from.Value.Second );
            parameters.Add( DataAccess.CreateParameterDateTime( fromDate ) );
            return String.Format( " {0} >= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateFromDateWithAnd(
            DateTime? from,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (from == null)
                return String.Empty;

            DateTime from12am = new DateTime( from.Value.Year, from.Value.Month, from.Value.Day, 0, 0, 0 );
            parameters.Add( DataAccess.CreateParameterDateTime( from12am ) );
            return String.Format( " AND {0} >= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateFromDateFor24HoursWithAnd(
            DateTime? from,
            ArrayList parameters,
            string parameterName,
            string dateFieldName )
        {
            if (from == null)
                return String.Empty;

            DateTime fromDate = new DateTime( from.Value.Year, from.Value.Month, from.Value.Day,
                from.Value.Hour, from.Value.Minute, from.Value.Second );
            parameters.Add( DataAccess.CreateParameterDateTime( fromDate ) );
            return String.Format( " AND {0} >= @{1} ", dateFieldName, parameterName );
        }

        public static string CreateToDateWithAnd(
            DateTime? to,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (to == null)
                return String.Empty;

            DateTime toLastSecond = new DateTime( to.Value.Year, to.Value.Month, to.Value.Day, 23, 59, 59 );
            parameters.Add( DataAccess.CreateParameterDateTime( toLastSecond ) );
            return String.Format( " AND {0} <= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateToDateFor24HoursWithAnd(
            DateTime? to,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (to == null)
                return String.Empty;

            DateTime toLastDate = new DateTime( to.Value.Year, to.Value.Month, to.Value.Day,
                to.Value.Hour, to.Value.Minute, to.Value.Second );
            parameters.Add( DataAccess.CreateParameterDateTime( toLastDate ) );
            return String.Format( " AND {0} <= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateFromDateWithAnd(
            string from,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (string.IsNullOrEmpty( from ))
                return String.Empty;

            DateTime fromDate = Utilities.ConvertToDateTime( from );

            DateTime from12am = new DateTime( fromDate.Year, fromDate.Month, fromDate.Day, 0, 0, 0 );
            parameters.Add( DataAccess.CreateParameterDateTime( from12am ) );
            return String.Format( " AND {0} >= @{1} ", dataFieldName, parameterName );
        }

        public static string CreateToDateWithAnd(
            string to,
            ArrayList parameters,
            string parameterName,
            string dataFieldName )
        {
            if (string.IsNullOrEmpty( to ))
                return String.Empty;

            DateTime toDate = Utilities.ConvertToDateTime( to );

            DateTime toLastSecond = new DateTime( toDate.Year, toDate.Month, toDate.Day, 23, 59, 59 );
            parameters.Add( DataAccess.CreateParameterDateTime( toLastSecond ) );
            return String.Format( " AND {0} <= @{1} ", dataFieldName, parameterName );
        }
    }
}
