using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Marketing;
using Vevo.Shared.Utilities;

namespace Vevo.Data
{
    public class GiftRegistryItemRepository : IGiftRegistryItemRepository
    {
        #region Private

        private const string RepositoryName = "GiftRegistryItemRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetGiftRegistryItemIDSignature = "GetGiftRegistryItemID";
        private const string GetAllByGiftRegistryIDSignature = "GetAllByGiftRegistryID";
        private const string CanBeDeletedByGiftRegistryIDSignature = "CanBeDeletedByGiftRegistryID";
        private const string CanBeDeletedByGiftRegistryItemIDSignature = "CanBeDeletedByGiftRegistryItemID";
        private const string TableName = "GiftRegistryItem";

        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );

        private GiftRegistryItemRepositoryNoCache _repository = new GiftRegistryItemRepositoryNoCache();

        #endregion

        #region Constructors

        public GiftRegistryItemRepository()
        {
        }

        public GiftRegistryItemRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public GiftRegistryItem Save( GiftRegistryItem giftRegistryItem )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            GiftRegistryItem newGiftRegistryItem = _repository.Save( giftRegistryItem );
            _dataCache.ClearRepositoryCache();
            return newGiftRegistryItem;
        }

        public GiftRegistryItem GetOne( string giftRegistryItemID )
        {
            GiftRegistryItem result = (GiftRegistryItem) _dataCache.GetValue( GetOneSignature, _cacheDependency, giftRegistryItemID );

            if (result == null)
            {
                result = _repository.GetOne( giftRegistryItemID );
                _dataCache.SetValue( GetOneSignature, result, giftRegistryItemID );
            }

            return result;
        }

        public void Delete( string giftRegistryItemID )
        {
            _repository.Delete( giftRegistryItemID );
            _dataCache.ClearRepositoryCache();
        }

        public void DeleteByGiftRegistryID( string giftRegistryID )
        {
            _repository.DeleteByGiftRegistryID( giftRegistryID );
            _dataCache.ClearRepositoryCache();
        }

        public IList<GiftRegistryItem> GetAllByGiftRegistryID( string giftRegistryID )
        {
            IList<GiftRegistryItem> list = (IList<GiftRegistryItem>) _dataCache.GetValue(
                    GetAllByGiftRegistryIDSignature,
                    _cacheDependency,
                    giftRegistryID
                    );

            if (list == null)
            {
                list = _repository.GetAllByGiftRegistryID( giftRegistryID );
                _dataCache.SetValue(
                    GetAllByGiftRegistryIDSignature,
                    list,
                    giftRegistryID
                    );
            }

            return list;
        }

        public bool CanBeDeletedByGiftRegistryID( string giftRegistryID )
        {
            object result = _dataCache.GetValue(
                    CanBeDeletedByGiftRegistryIDSignature,
                    _cacheDependency,
                    giftRegistryID
                    );

            if (result == null)
            {
                result = _repository.CanBeDeletedByGiftRegistryID( giftRegistryID );
                _dataCache.SetValue(
                    CanBeDeletedByGiftRegistryIDSignature,
                    result,
                    giftRegistryID
                    );
            }

            return ConvertUtilities.ToBoolean( result );
        }

        public bool CanBeDeletedByGiftRegistryItemID( string giftRegistryItemID )
        {
            object result = _dataCache.GetValue(
                    CanBeDeletedByGiftRegistryItemIDSignature,
                    _cacheDependency,
                    giftRegistryItemID
                    );

            if (result == null)
            {
                result = _repository.CanBeDeletedByGiftRegistryItemID( giftRegistryItemID );
                _dataCache.SetValue(
                    CanBeDeletedByGiftRegistryItemIDSignature,
                    result,
                    giftRegistryItemID
                    );
            }

            return ConvertUtilities.ToBoolean( result );
        }

        public string GetGiftRegistryItemID(
            string giftRegistryID,
            string productID,
            string optionItems,
            decimal giftCertificatePrice,
            bool isGiftCertificate,
            string recipient,
            string personalNote,
            bool needPhysical )
        {
            object result = _dataCache.GetValue(
                    GetGiftRegistryItemIDSignature,
                    _cacheDependency,
                    giftRegistryID,
                    productID,
                    optionItems,
                    giftCertificatePrice,
                    isGiftCertificate.ToString(),
                    recipient,
                    personalNote,
                    needPhysical.ToString()
                    );

            if (result == null)
            {
                result = _repository.GetGiftRegistryItemID( giftRegistryID,
                    productID,
                    optionItems,
                    giftCertificatePrice,
                    isGiftCertificate,
                    recipient,
                    personalNote,
                    needPhysical );
                _dataCache.SetValue(
                    GetGiftRegistryItemIDSignature,
                    result,
                    giftRegistryID,
                    productID,
                    optionItems,
                    giftCertificatePrice,
                    isGiftCertificate.ToString(),
                    recipient,
                    personalNote,
                    needPhysical.ToString()
                    );
            }

            return result.ToString();
        }

        #endregion
    }
}
