﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using Vevo.Shared.DataAccess;

namespace Vevo.Data.Implementation
{
    internal class CustomerStoreAccess
    {
        #region Private

        private IList<String> ConvertToStoreIDs(DataTable table)
        {
            IList<String> list = new List<String>();
            foreach (DataRow row in table.Rows)
            {
                list.Add(row["StoreID"].ToString());
            }

            return list;
        }

        #endregion

        #region Public Methods

        public void SaveAll(string customerID, IList<String> storeIDs)
        {
            DeleteByCustomerID(customerID);
            Create(customerID, storeIDs);
        }

        public void Create(string customerID, IList<String> storeIDs)
        {
            foreach (string storeID in storeIDs)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO CustomerStore (CustomerID, StoreID) " +
                    "VALUES (@CustomerID, @StoreID); ",
                    DataAccess.CreateParameterString(customerID),
                    DataAccess.CreateParameterString(storeID));

                if (result != 1)
                {
                    Exception exception = new ApplicationException(
                            "Failed creating customer. " +
                        "Inserting into CustomerStore returns " + result.ToString());
                    DataAccessHelper.LogError(exception);
                    throw exception;
                }
            }
        }

        public void DeleteByCustomerID(string customerID)
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM CustomerStore " +
                "WHERE CustomerID = @CustomerID; ",
                DataAccess.CreateParameterString(customerID));
        }

        public void DeleteByStoreID(string storeID)
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM Store " +
                "WHERE StoreID = @StoreID; ",
                DataAccess.CreateParameterString(storeID));
        }

        public IList<String> GetByCustomerID(string customerID)
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT StoreID " +
                "FROM CustomerStore " +
                "WHERE CustomerID = @CustomerID; ",
                DataAccess.CreateParameterString(customerID));

            return ConvertToStoreIDs(table);
        }

        #endregion
    }
}
