﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Vevo.Domain.Payments;
using System.Data;
using Vevo.Shared.Utilities;
using Vevo.Shared.DataAccess;

namespace Vevo.Data.Implementation
{
    internal class PaymentOptionStoreAccess
    {
        private const string AllPaymentOptionStoreFields =
           " Name, StoreID, IsEnabled ";

        private PaymentOptionStore CreateOneFromRow( DataRow row )
        {
            PaymentOptionStore poStore = new PaymentOptionStore();
            poStore.Name = row["Name"].ToString();
            poStore.StoreID = row["StoreID"].ToString();
            poStore.IsEnabled = ConvertUtilities.ToBoolean( row["IsEnabled"] );

            return poStore;
        }

        public PaymentOptionStore Create( PaymentOptionStore poStore )
        {
            DataAccess.ExecuteNonQuery(
                "INSERT INTO PaymentOptionStore " +
                " (" + AllPaymentOptionStoreFields + ") " +
                "VALUES (@Name,@StoreID, @IsEnabled);",
                DataAccess.CreateParameterString( poStore.Name ),
                DataAccess.CreateParameterString( poStore.StoreID ),
                DataAccess.CreateParameterBool( poStore.IsEnabled )
            );

            return poStore;
        }

        public void Delete( string storeID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM PaymentOptionStore " +
                "WHERE StoreID = @StoreID ;",
                DataAccess.CreateParameterString( storeID )
            );
        }

        public void DeleteByName( string name )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM PaymentOptionStore " +
                "WHERE Name = @name ;",
                DataAccess.CreateParameterString( name )
);
        }

        public IList<PaymentOptionStore> GetAll()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllPaymentOptionStoreFields +
                "FROM PaymentOptionStore ;"
                 );
            if (table.Rows.Count > 0)
            {
                List<PaymentOptionStore> list = new List<PaymentOptionStore>();
                foreach (DataRow row in table.Rows)
                {
                    list.Add( CreateOneFromRow( row ) );
                }
                return list;
            }
            else
                return null;
        }

        public IList<PaymentOptionStore> GetAllByName(string name)
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllPaymentOptionStoreFields +
                "FROM PaymentOptionStore WHERE Name = @Name ;",
                DataAccess.CreateParameterString( name )
                );
            if (table.Rows.Count > 0)
            {
                List<PaymentOptionStore> list = new List<PaymentOptionStore>();
                foreach (DataRow row in table.Rows)
                {
                    list.Add( CreateOneFromRow( row ) );
                }
                return list;
            }
            else
                return null;
        }
    }
}

