﻿using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain.Products;
using System.Data;
using Vevo.Domain;
using Vevo.Shared.Utilities;
using Vevo.Shared.DataAccess;

namespace Vevo.Data.Implementation
{
    internal class ProductKitAccess
    {
        #region Private

        private IList<ProductKit> ConvertProductKitTableToList( Culture culture, DataTable table )
        {
            IList<ProductKit> list = new List<ProductKit>();

            foreach (DataRow row in table.Rows)
            {
                ProductKit productKit = new ProductKit( culture );
                //productKit.ProductID = row["ProductID"].ToString();
                productKit.ProductKitGroupID = row["ProductKitGroupID"].ToString();
                productKit.SortOrder = ConvertUtilities.ToInt32( row["SortOrder"] );

                list.Add( productKit );
            }

            return list;
        }

        #endregion


        #region Public Methods

        public void DeleteByProductID( string productID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductKit " +
                "WHERE ProductID = @ProductID ;",
                DataAccess.CreateParameterString( productID ) );

            foreach (string productKitGroupID in GetProductKitGroupIDsByProductID( productID ))
            {
                DataAccessContext.ProductKitGroupRepository.Delete( productKitGroupID );
            }
        }

        public int DeleteByProductKitGroupID( string productKitGroupID )
        {
            return DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductKit " +
                "WHERE ProductKitGroupID = @ProductKitGroupID ;",
                DataAccess.CreateParameterString( productKitGroupID ) );
        }

        private void InsertProductKit( string productID, IList<ProductKit> productKitList )
        {
            foreach (ProductKit productKit in productKitList)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductKit (ProductID ,ProductKitGroupID, SortOrder ) " +
                    "VALUES ( @ProductID, @ProductKitGroupID, @SortOrder );",
                    DataAccess.CreateParameterString( productID ),
                    DataAccess.CreateParameterString( productKit.ProductKitGroupID ),
                    DataAccess.CreateParameterInt32( productKit.SortOrder ) );
            }
        }

        public void SaveAll( string productID, IList<ProductKit> productKitList )
        {
            DeleteByProductID( productID );
            InsertProductKit( productID, productKitList );
        }

        public IList<ProductKit> GetByProductID( Culture culture, string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID ,ProductKitGroupID, SortOrder " +
                "FROM ProductKit " +
                "WHERE ProductID = @ProductID " +
                "ORDER BY SortOrder; ",
                DataAccess.CreateParameterString( productID ) );

            return ConvertProductKitTableToList( culture, table );
        }

        public IList<String> GetProductKitGroupIDsByProductID( string productID )
        {
            IList<String> groupIDs = new List<String>();

            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID ,ProductKitGroupID, SortOrder " +
                "FROM ProductKit " +
                "WHERE ProductID = @ProductID; ",
                DataAccess.CreateParameterString( productID ) );

            foreach (DataRow row in table.Rows)
            {
                groupIDs.Add( row["ProductKitGroupID"].ToString() );
            }

            return groupIDs;
        }

        #endregion
    }
}
