using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain.Tax;
using Vevo.Shared.DataAccess;
using System.Data;
using Vevo.Domain.DataInterfaces;
using System.Collections;
using Vevo.Base.Data.Implementation;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data.Implementation
{
    internal class TaxClassAccess : BaseListedDataAccess<string, TaxClass>
    {
        #region Private

        private const string AllTaxClassFields = "TaxClassID, TaxClassName ";

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else
                return "ORDER BY " + sortBy;
        }

        #endregion
        #region Protected

        protected override void Create( string parentID, TaxClass item )
        {
            throw new Exception( "The method or operation is not implemented." );
        }

        protected override void Update( string parentID, TaxClass item )
        {
            throw new Exception( "The method or operation is not implemented." );
        }

        protected override void Delete( string parentID, TaxClass item )
        {
            throw new Exception( "The method or operation is not implemented." );
        }

        #endregion

        #region Public Methods

        public TaxClass Create( TaxClass taxClass )
        {
            taxClass.TaxClassID = DataAccess.ExecuteScalar(
                "INSERT INTO TaxClass( TaxClassName ) " +
                "VALUES ( @TaxClassName ); " +
                "SELECT @@Identity",
                DataAccess.CreateParameterString( taxClass.TaxClassName )
            );

            return taxClass;
        }

        public TaxClass Update( TaxClass taxClass )
        {
            DataAccess.ExecuteSelect(
              "UPDATE TaxClass " +
              "SET " +
              "   TaxClassName = @TaxClassName " +
              "WHERE TaxClassID = @TaxClassID",
              DataAccess.CreateParameterString( taxClass.TaxClassName ),
              DataAccess.CreateParameterString( taxClass.TaxClassID ) );

            return taxClass;
        }

        public void Delete( string taxClassID )
        {
            DataAccess.ExecuteNonQuery(
                    "DELETE " +
                    "FROM TaxClass " +
                    "WHERE TaxClassID = @TaxClassID; ",
                    DataAccess.CreateParameterString( taxClassID ) );
        }

        public DataTable SearchTaxClasses(
            string sortBy,
            SearchFilter searchFilter,
            out int howManyItems )
        {
            ArrayList parameterList = new ArrayList();
            SearchFilterHelperNew searchFilterHelper = new SearchFilterHelperNew();
            string commandSearch = searchFilterHelper.CreateCommandWithWhere( searchFilter, searchFilter.FieldName, parameterList );

            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassFields +
                "FROM TaxClass " +
                commandSearch +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.ConvertArrayListToDbParameters( parameterList )
            );

            howManyItems = table.Rows.Count;

            DataColumn[] keys = new DataColumn[] { table.Columns["TaxClassID"] };
            table.PrimaryKey = keys;
            return table;
        }

        public IList<TableSchemaItem> GetTableSchemas()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassFields +
                "FROM TaxClass " +
                "WHERE 0 = 1; " );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        #endregion
    }
}
