using System.Collections.Generic;
using System.IO;
using System.Text;
using Vevo.Shared.Utilities;

namespace Vevo.Domain.Orders
{
    public class OrderExporter
    {
        #region Private

        private string GenerateHeader()
        {
            string header = "\"OrderID\"\t\"CustomerID\"\t\"OrderDate\"\t\"UserName\"\t\"FirstName\"\t\"LastName\"\t\"Company\"\t\"Address1\"\t" +
                    "\"Address2\"\t\"City\"\t\"State\"\t\"Zip\"\t\"Country\"\t\"Phone\"\t\"Fax\"\t\"Email\"\t\"ShippingFirstName\"\t" +
                    "\"ShippingLastName\"\t\"ShippingCompany\"\t\"ShippingAddress1\"\t\"ShippingAddress2\"\t\"ShippingCity\"\t" +
                    "\"ShippingState\"\t\"ShippingZip\"\t\"ShippingCountry\"\t\"ShippingPhone\"\t\"ShippingFax\"\t\"ShippingResidential\"\t" +
                    "\"CustomerComments\"\t\"ShippedDate\"\t\"ShippingMethod\"\t\"PaymentMethod\"\t\"GatewayPaymentStatus\"\t\"GatewayOrderID\"\t" +
                    "\"PaymentComplete\"\t\"Processed\"\t\"Status\"\t\"Cancelled\"\t\"IPAddress\"\t\"CouponID\"\t\"Subtotal\"\t\"Tax\"\t" +
                    "\"ShippingCost\"\t\"CouponDiscount\"\t\"BaseCurrencyCode\"\t\"UserCurrencyCode\"\t\"UserConversionRate\"\t\"InvoiceNotes\"\t" +
                    "\"ShippingID\"\t\"GiftCertificateCode\"\t\"GiftCertificate\"\t\"TrackingNumber\"\t\"TrackingMethod\"\t\"GiftRegistryID\"\t" +
                    "\"ShowShippingAddress\"\t\"HandlingFee\"\t\"QbPostDate\"\t\"QbReferenceCode\"\t\"ContainsRecurring\"\t\"ParentID\"\t" +
                    "\"PaymentToken\"\t\"AvsAddrStatus\"\t\"AvsZipStatus\"\t\"CvvStatus\"";

            if (KeyUtilities.IsMultistoreLicense())
                return header + "\t\"StoreID\"";
            else
                return header;
        }

        private string GenerateDetail( Order order )
        {
            string orderID, customerID, orderDate, userName, firstName, lastName, company, address1, address2, city, state;
            string zip, country, phone, fax, email, shippingFirstName, shippingLastName, shippingCompany, shippingAddress1;
            string shippingAddress2, shippingCity, shippingState, shippingZip, shippingCountry, shippingPhone, shippingFax;
            string shippingResidential, customerComments, shippedDate, shippingMethod, paymentMethod, gatewayPaymentStatus;
            string gatewayOrderID, paymentComplete, processed, status, cancelled, iPAddress, couponID, subtotal, tax;
            string shippingCost, couponDiscount, baseCurrencyCode, userCurrencyCode, userConversionRate, invoiceNotes;
            string shippingID, giftCertificateCode, giftCertificate, trackingNumber, trackingMethod, giftRegistryID;
            string showShippingAddress, handlingFee, qbPostDate, qbReferenceCode, containsRecurring, parentID, paymentToken;
            string avsAddressStatus, avsZipStatus, cvvStatus, storeID;

            orderID = order.OrderID;
            customerID = order.CustomerID;
            orderDate = ConvertUtilities.ToString( order.OrderDate );
            userName = order.UserName;
            firstName = order.Billing.FirstName;
            lastName = order.Billing.LastName;
            company = order.Billing.Company;
            address1 = order.Billing.Address1;
            address2 = order.Billing.Address2;
            city = order.Billing.City;
            state = order.Billing.State;
            zip = order.Billing.Zip;
            country = order.Billing.Country;
            phone = order.Billing.Phone;
            fax = order.Billing.Fax;
            email = order.Email;
            shippingFirstName = order.Shipping.FirstName;
            shippingLastName = order.Shipping.LastName;
            shippingCompany = order.Shipping.Company;
            shippingAddress1 = order.Shipping.Address1;
            shippingAddress2 = order.Shipping.Address2;
            shippingCity = order.Shipping.City;
            shippingState = order.Shipping.State;
            shippingZip = order.Shipping.Zip;
            shippingCountry = order.Shipping.Country;
            shippingPhone = order.Shipping.Phone;
            shippingFax = order.Shipping.Fax;
            shippingResidential = ConvertUtilities.ToString( order.Shipping.Residential );
            customerComments = order.CustomerComments.Replace( "\n", "" );
            shippedDate = ConvertUtilities.ToString( order.ShippedDate );
            shippingMethod = order.ShippingMethod;
            paymentMethod = order.PaymentMethod;
            gatewayPaymentStatus = order.GatewayPaymentStatus;
            gatewayOrderID = order.GatewayOrderID;
            paymentComplete = ConvertUtilities.ToString( order.PaymentComplete );
            processed = ConvertUtilities.ToString( order.Processed );
            status = order.Status;
            cancelled = ConvertUtilities.ToString( order.Cancelled );
            iPAddress = order.IPAddress;
            couponID = order.CouponID;
            subtotal = ConvertUtilities.ToString( order.Subtotal );
            tax = ConvertUtilities.ToString( order.Tax );
            shippingCost = ConvertUtilities.ToString( order.ShippingCost );
            couponDiscount = ConvertUtilities.ToString( order.CouponDiscount );
            baseCurrencyCode = order.BaseCurrencyCode;
            userCurrencyCode = order.UserCurrencyCode;
            userConversionRate = ConvertUtilities.ToString( order.UserConversionRate );
            invoiceNotes = order.InvoiceNotes.Replace( "\n", "" );
            shippingID = order.ShippingID;
            giftCertificateCode = order.GiftCertificateCode;
            giftCertificate = ConvertUtilities.ToString( order.GiftCertificate );
            trackingNumber = order.TrackingNumber;
            trackingMethod = order.TrackingMethod;
            giftRegistryID = order.GiftRegistryID;
            showShippingAddress = ConvertUtilities.ToString( order.ShowShippingAddress );
            handlingFee = ConvertUtilities.ToString( order.HandlingFee );
            qbPostDate = ConvertUtilities.ToString( order.QbPostDate );
            qbReferenceCode = order.QbReferenceCode;
            containsRecurring = ConvertUtilities.ToString( order.ContainsRecurring );
            parentID = order.ParentID;
            paymentToken = order.PaymentToken;
            avsAddressStatus = order.AvsAddrStatus;
            avsZipStatus = order.AvsZipStatus;
            cvvStatus = order.CvvStatus;
            storeID = order.StoreID;

            string details = orderID + "\t" + customerID + "\t" + orderDate + "\t" + userName + "\t" + firstName + "\t" + lastName + "\t" +
                company + "\t" + address1 + "\t" + address2 + "\t" + city + "\t" + state + "\t" + zip + "\t" + country + "\t" + phone + "\t" +
                fax + "\t" + email + "\t" + shippingFirstName + "\t" + shippingLastName + "\t" + shippingCompany + "\t" + shippingAddress1 + "\t" +
                shippingAddress2 + "\t" + shippingCity + "\t" + shippingState + "\t" + shippingZip + "\t" + shippingCountry + "\t" +
                shippingPhone + "\t" + shippingFax + "\t" + shippingResidential + "\t" + customerComments + "\t" + shippedDate + "\t" +
                shippingMethod + "\t" + paymentMethod + "\t" + gatewayPaymentStatus + "\t" + gatewayOrderID + "\t" + paymentComplete + "\t" +
                processed + "\t" + status + "\t" + cancelled + "\t" + iPAddress + "\t" + couponID + "\t" + subtotal + "\t" + tax + "\t" +
                shippingCost + "\t" + couponDiscount + "\t" + baseCurrencyCode + "\t" + userCurrencyCode + "\t" + userConversionRate + "\t" +
                invoiceNotes + "\t" + shippingID + "\t" + giftCertificateCode + "\t" + giftCertificate + "\t" + trackingNumber + "\t" +
                trackingMethod + "\t" + giftRegistryID + "\t" + showShippingAddress + "\t" + handlingFee + "\t" + qbPostDate + "\t" +
                qbReferenceCode + "\t" + containsRecurring + "\t" + parentID + "\t" + paymentToken + "\t" +
                avsAddressStatus + "\t" + avsZipStatus + "\t" + cvvStatus;

            if (KeyUtilities.IsMultistoreLicense())
                return details + "\t" + storeID;
            else
                return details;
        }

        #endregion


        #region Public Methods

        public MemoryStream ExportToStream( IList<Order> ordersList )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream, Encoding.Unicode );

            if (ordersList.Count > 0)
            {
                sw.WriteLine( GenerateHeader() );
                string details;
                foreach (Order order in ordersList)
                {
                    details = GenerateDetail( order );
                    sw.WriteLine( details );
                }
            }


            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }

        #endregion


    }
}
