using System;
using System.Collections.Generic;
using System.Net;
using System.Net.Security;
using System.Text;
using System.Security.Cryptography.X509Certificates;
using Vevo.Shared.Domain.SystemServices;

namespace Vevo.Domain.Security
{
    public class SslPolicy
    {
        #region Private

        private string[] _pageSSL = new string[] 
        { 
            // Pages under "My Account"
            "MyAccount.aspx",
            "AccountDetails.aspx",
            "ChangeUserPassword.aspx",
            "OrderHistory.aspx",
            "GiftCertificate.aspx",
            "AccountDashboard.aspx",

            // Pages under "Affiliates"
            "AffiliateLogin.aspx",
            "AffiliateCommission.aspx",
            "AffiliateCommissionSearch.aspx",
            "AffiliateRegister.aspx",
            "AffiliateMain.aspx",
            "AffiliateDetails.aspx",
            "AffiliateGenerateLink.aspx",
            "AffiliateRegister.aspx",
            "AffiliateRegisterFinish.aspx",
            "AffiliateDashboard.aspx",

            // Pages during checkout
            "Register.aspx",
            "UserLogin.aspx",
            "Checkout.aspx",
            "Payment.aspx", 
            "Shipping.aspx",
            "Directpaymentsale.aspx",
            "OrderSummary.aspx", 
            "Checkoutcomplete.aspx", 
        };


        // Custom SSL certificate policy that always pass self-signed certificates.
        private static bool AlwaysPassCertificateValidationCallback(
            Object sender,
            X509Certificate certificate,
            X509Chain chain,
            SslPolicyErrors sslPolicyErrors )
        {
            return true;
        }


        #endregion


        #region Public Methods

        // Set up to accept untrusted (self-certified) SSL certificate for testing.
        // If the current website is a local machine (with "localhost" or "192.168.x.x" or "127.0.0.1"),
        // always accept the certificate even for a self-signed SSL certificate.
        //
        // Otherwise, only accepts the certificate that is from a trusted source (e.g. from VeriSign).
        public void SetUpCertificatePolicy( string currentWebsiteUrl )
        {
            try
            {
                Uri uri = new Uri( currentWebsiteUrl );
                if (String.Compare( uri.Host, "localhost", true ) == 0
                    || uri.Host.StartsWith( "192.168." )
                    || uri.Host == "127.0.0.1")
                {
                    ServicePointManager.ServerCertificateValidationCallback = AlwaysPassCertificateValidationCallback;
                }
                else
                {
                    ServicePointManager.ServerCertificateValidationCallback = null;
                }
            }
            catch (Exception ex)
            {
                SaveLogFile.SaveLog( ex );
            }
        }

        public bool VerifyCommandPageSsl( bool isSecureConnection )
        {
            if (DataAccessContext.Configurations.GetBoolValue( "EnableSsl" ))
            {
                if (isSecureConnection)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
            else
            {
                return true;
            }
        }

        public bool RequiresRedirect( string url, out string newUrl )
        {
            newUrl = url;
            if (!DataAccessContext.Configurations.GetBoolValue( "EnableSsl" ))
                return false;

            bool required = false;
            foreach (string page in _pageSSL)
            {
                // Check only path string, not query string.
                Uri uri = new Uri( url );
                if (uri.AbsolutePath.ToLower().Contains( page.ToLower() ))
                {
                    required = true;
                }
            }

            if (required)
            {
                if (url.ToLower().Contains( "http://" ))
                {
                    newUrl = "https://" + url.Substring( "http://".Length );
                    return true;
                }
            }
            else
            {
                if (url.ToLower().Contains( "https://" ))
                {
                    newUrl = "http://" + url.Substring( "https://".Length );
                    return true;
                }
            }

            return false;
        }

        #endregion
    }
}
