using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI.WebControls;

namespace Vevo.Reports
{
    public enum PeriodType
    {
        Last30Days,
        Last24Hours,
        Today,
        Yesterday,
        Last7Days,
        ThisMonth,
        LastMonth,
        ThisYear,
        Last3Years,
        YearToDate,
        Custom,
        Unknow
    }

    public enum SaleReportType
    {
        OrderTotals,
        AverageOrderTotals,
        NumberOfOrder,
        NumberOfItemsSold,
        AverageItemPerOrder,
        Unknow
    }

    public enum BestSellReportType
    {
        NumberOfProduct,
        ProductTotalPrice,
        Unknow
    }

    public enum CustomerReportType
    {
        UserRegistration,
        TopNumberOfProductBuyer,
        TopProductTotalPriceBuyer,
        Unknow
    }

    public enum NumberOfItemType
    {
        Ten,
        TwentyFive,
        All,
        Unknow
    }

    public static class ReportFilterUtilities
    {
        public static ListItemCollection GetPeriodList()
        {
            ListItemCollection list = new ListItemCollection();
            list.Add( new ListItem( "Last month", PeriodType.LastMonth.ToString() ) );
            list.Add( new ListItem( "Last 30 days", PeriodType.Last30Days.ToString() ) );
            list.Add( new ListItem( "Last 7 days", PeriodType.Last7Days.ToString() ) );
            list.Add( new ListItem( "Yesterday", PeriodType.Yesterday.ToString() ) );
            list.Add( new ListItem( "Last 24 hours", PeriodType.Last24Hours.ToString() ) );
            list.Add( new ListItem( "Today", PeriodType.Today.ToString() ) );
            list.Add( new ListItem( "This month", PeriodType.ThisMonth.ToString() ) );
            list.Add( new ListItem( "This year", PeriodType.ThisYear.ToString() ) );
            list.Add( new ListItem( "Last 3 years", PeriodType.Last3Years.ToString() ) );
            list.Add( new ListItem( "Year to date", PeriodType.YearToDate.ToString() ) );
            list.Add( new ListItem( "Custom", PeriodType.Custom.ToString() ) );

            return list;
        }

        public static ListItemCollection GetSaleReportList()
        {
            ListItemCollection list = new ListItemCollection();
            list.Add( new ListItem( "Order Total", SaleReportType.OrderTotals.ToString() ) );
            list.Add( new ListItem( "Average Order Total", SaleReportType.AverageOrderTotals.ToString() ) );
            list.Add( new ListItem( "Number of Orders", SaleReportType.NumberOfOrder.ToString() ) );
            list.Add( new ListItem( "Number of Items Sold", SaleReportType.NumberOfItemsSold.ToString() ) );
            list.Add( new ListItem( "Average Item Per Order", SaleReportType.AverageItemPerOrder.ToString() ) );

            return list;
        }

        public static ListItemCollection GetBestSellingReportList()
        {
            ListItemCollection list = new ListItemCollection();
            list.Add( new ListItem( "Number Of Product", BestSellReportType.NumberOfProduct.ToString() ) );
            list.Add( new ListItem( "Product Total Price", BestSellReportType.ProductTotalPrice.ToString() ) );

            return list;
        }

        public static ListItemCollection GetCustomerReportList()
        {
            ListItemCollection list = new ListItemCollection();
            list.Add( new ListItem( "Customer Registration", CustomerReportType.UserRegistration.ToString() ) );
            list.Add( new ListItem( "Top Buyer by Quantity", CustomerReportType.TopNumberOfProductBuyer.ToString() ) );
            list.Add( new ListItem( "Top Buyer by Price", CustomerReportType.TopProductTotalPriceBuyer.ToString() ) );

            return list;
        }

        public static ListItemCollection GetNumberOfItemsList()
        {
            ListItemCollection list = new ListItemCollection();
            list.Add( new ListItem( "10", NumberOfItemType.Ten.ToString() ) );
            list.Add( new ListItem( "25", NumberOfItemType.TwentyFive.ToString() ) );
            list.Add( new ListItem( "All", NumberOfItemType.All.ToString() ) );

            return list;
        }

        public static PeriodType ConvertToPeriodType( string period )
        {
            if (String.IsNullOrEmpty( period ) ||
                !Enum.IsDefined( typeof( PeriodType ), period ))
                return PeriodType.Unknow;
            else
                return (PeriodType) Enum.Parse( typeof( PeriodType ), period );
        }

        public static SaleReportType ConvertToSaleReportType( string saleReportType )
        {
            if (String.IsNullOrEmpty( saleReportType ) ||
                !Enum.IsDefined( typeof( SaleReportType ), saleReportType ))
                return SaleReportType.Unknow;
            else
                return (SaleReportType) Enum.Parse( typeof( SaleReportType ), saleReportType );
        }

        public static BestSellReportType ConvertToBestSellReportType( string bestSellReportType )
        {
            if (String.IsNullOrEmpty( bestSellReportType ) ||
                !Enum.IsDefined( typeof( BestSellReportType ), bestSellReportType ))
                return BestSellReportType.Unknow;
            else
                return (BestSellReportType) Enum.Parse( typeof( BestSellReportType ), bestSellReportType );
        }

        public static CustomerReportType ConvertToCustomerReportType( string customerReportType )
        {
            if (String.IsNullOrEmpty( customerReportType ) ||
                !Enum.IsDefined( typeof( CustomerReportType ), customerReportType ))
                return CustomerReportType.Unknow;
            else
                return (CustomerReportType) Enum.Parse( typeof( CustomerReportType ), customerReportType );
        }

        public static NumberOfItemType ConvertToNumberOfItemType( string numberOfItemType )
        {
            if (String.IsNullOrEmpty( numberOfItemType ) ||
                !Enum.IsDefined( typeof( NumberOfItemType ), numberOfItemType ))
                return NumberOfItemType.Unknow;
            else
                return (NumberOfItemType) Enum.Parse( typeof( NumberOfItemType ), numberOfItemType );
        }

        public static String ConvertToPeriodText( PeriodType periodType )
        {
            ListItemCollection list = GetPeriodList();
            ListItem item = list.FindByValue( periodType.ToString() );
            if (item == null)
                return "No Parameter";
            else
                return item.Text.ToString();
        }

        public static String ConvertToSaleReportText( SaleReportType saleReportType )
        {
            ListItemCollection list = GetSaleReportList();
            ListItem item = list.FindByValue( saleReportType.ToString() );
            if (item == null)
                return "No Parameter";
            else
                return item.Text.ToString();
        }

        public static String ConvertToBestSellReportText( BestSellReportType bestSellReportType )
        {
            ListItemCollection list = GetBestSellingReportList();
            ListItem item = list.FindByValue( bestSellReportType.ToString() );
            if (item == null)
                return "No Parameter";
            else
                return item.Text.ToString();
        }

        public static String ConvertToCustomerReportText( CustomerReportType customerReportType )
        {
            ListItemCollection list = GetCustomerReportList();
            ListItem item = list.FindByValue( customerReportType.ToString() );
            if (item == null)
                return "No Parameter";
            else
                return item.Text.ToString();
        }

        public static String ConvertToNumberOfItemText( NumberOfItemType numberOfItemType )
        {
            ListItemCollection list = GetNumberOfItemsList();
            ListItem item = list.FindByValue( numberOfItemType.ToString() );
            if (item == null)
                return "No Parameter";
            else
                return item.Text.ToString();
        }

        public static void GetOrderDateRange( PeriodType period, out DateTime startOrderDate, out DateTime endOrderDate )
        {
            DateTime currentDate = DateTime.Now;
            startOrderDate = DateTime.Now;
            endOrderDate = DateTime.Now;
            if (period == PeriodType.LastMonth)
            {
                startOrderDate = new DateTime( currentDate.Year, currentDate.Month, 1 ).AddMonths( -1 );
                endOrderDate = new DateTime( currentDate.Year, currentDate.Month, 1 ).AddDays( -1 );
            }
            else if (period == PeriodType.Last30Days)
            {
                startOrderDate = currentDate.AddDays( -30 );
                endOrderDate = currentDate.AddDays( -1 );
            }
            else if (period == PeriodType.Last7Days)
            {
                startOrderDate = currentDate.AddDays( -7 );
                endOrderDate = currentDate.AddDays( -1 );
            }
            else if (period == PeriodType.Yesterday)
            {
                startOrderDate = currentDate.AddDays( -1 );
                endOrderDate = startOrderDate;
            }
            else if (period == PeriodType.Last24Hours)
            {
                startOrderDate = currentDate.AddHours( -24 );
                endOrderDate = currentDate;
            }
            else if (period == PeriodType.Today)
            {
                startOrderDate = currentDate;
                endOrderDate = currentDate;
            }
            else if (period == PeriodType.ThisMonth)
            {
                startOrderDate = new DateTime( currentDate.Year, currentDate.Month, 1 );
                endOrderDate = new DateTime( currentDate.Year, currentDate.Month, 1 ).AddMonths( 1 ).AddSeconds( -1 );
            }
            else if (period == PeriodType.ThisYear)
            {
                startOrderDate = new DateTime( currentDate.Year, 1, 1 );
                endOrderDate = new DateTime( currentDate.Year, 12, 31 );
            }
            else if (period == PeriodType.Last3Years)
            {
                startOrderDate = new DateTime( currentDate.Year, 1, 1 ).AddYears( -3 );
                endOrderDate = new DateTime( currentDate.Year, 12, 31 );
            }
            else if (period == PeriodType.YearToDate)
            {
                startOrderDate = currentDate.AddYears(-1);
                endOrderDate = currentDate;
            }
        }

        public static PeriodType ResolveCustomPeriodType( DateTime startDate, DateTime endDate )
        {
            TimeSpan dateDifference = endDate.Subtract( startDate );
            if (dateDifference.Days > 60)
                return PeriodType.ThisYear;
            else if (dateDifference.Days == 0)
                return PeriodType.Today;
            else
                return PeriodType.ThisMonth;
        }
    }
}
