﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Configurations;
using Vevo.WebAppLib;

namespace Vevo.WebServices.Configurations
{
    public class ConfigurationService:IConfigurationService
    {
        private ConfigurationConstraints ConvertConfigurationToConstraints( Configuration config )
        {
            ConfigurationConstraints constraints = new ConfigurationConstraints();
            constraints.ConfigID = config.ConfigID;
            if (config.ConfigType == Configuration.ConfigurationType.DropDown)
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.DropDown;
            else if (config.ConfigType == Configuration.ConfigurationType.RadioButton)
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.RadioButton;
            else if (config.ConfigType == Configuration.ConfigurationType.TextBox)
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.TextBox;
            else if (config.ConfigType == Configuration.ConfigurationType.Upload)
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.Upload;
            else if (config.ConfigType == Configuration.ConfigurationType.UserControl)
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.UserControl;
            else
                constraints.ConfigType = ConfigurationConstraints.ConfigurationType.Unknow;

            constraints.DisplayUserControl = config.DisplayUserControl; ;
            constraints.EnablerConfigName = config.EnablerConfigName;
            constraints.FieldValidation = config.FieldValidation;
            constraints.Name = config.Name;
            constraints.Searchable = config.Searchable;
            constraints.SelectionValues = config.SelectionValues;
            constraints.SelectionNames = config.SelectionNames;
            constraints.SelectionImages = config.SelectionImages;
            constraints.ParentConfigName = config.ParentConfigName;

            constraints.ConfigurationValues = new List<ConfigurationValueConstraints>();
            foreach (ConfigurationValue value in config.Values)
            {
                ConfigurationValueConstraints const_value = new ConfigurationValueConstraints();
                const_value.CultureID = value.CultureID;
                const_value.ItemValue = value.ItemValue;
                const_value.StoreID = value.StoreID;
                constraints.ConfigurationValues.Add( const_value );
            }

            constraints.ConfigurationDescriptions = new List<ConfigurationDescriptionConstraints>();
            foreach (ConfigurationDescription desc in config.Descriptions)
            {
                ConfigurationDescriptionConstraints const_desc = new ConfigurationDescriptionConstraints();
                const_desc.CultureID = desc.CultureID;
                const_desc.Description = desc.Description;
                const_desc.DisplayName = desc.DisplayName;
                const_desc.Keyword = desc.Keyword;
                const_desc.MainGroup = desc.MainGroup;
                const_desc.SubGroup = desc.SubGroup;
                constraints.ConfigurationDescriptions.Add( const_desc );
            }

            return constraints;
        }

        public ConfigurationListResponseMessage ListConfigurations( ConfigurationListRequestMessage ListMessage )
        {
            ConfigurationListResponseMessage responseMessage = new ConfigurationListResponseMessage();
            if (WcfSessionPool.GetSession( ListMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                string[] searchField = {ListMessage.SearchFilter.FieldName};
                Culture culture = DataAccessContext.CultureRepository.GetOne( ListMessage.CultureID );
                IList<Configuration> config_result = DataAccessContext.ConfigurationRepository.SearchConfiguration( culture, "ConfigID", ListMessage.SearchFilter.Value1, searchField );
                responseMessage.Configurations = new List<ConfigurationConstraints>();
                foreach (Configuration config in config_result)
                {
                    responseMessage.Configurations.Add( ConvertConfigurationToConstraints( config ) );
                }
            }
            catch (Exception e)
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get configurations from repository";
            }

            return responseMessage;
        }
    }
}
