﻿using System;
using System.Collections.Generic;
using System.Text;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.WebAppLib;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Products;
using Vevo.Base.Domain;

namespace Vevo.WebServices.Departments
{
    public class DepartmentService:IDepartmentService
    {
        private DepartmentConstraints ConvertDepartmentToConstraints( Department department, Culture culture )
        {
            DepartmentConstraints constraints = new DepartmentConstraints();
            constraints.DepartmentID = department.DepartmentID;
            constraints.DepartmentListLayoutPath = department.DepartmentListLayoutPath;
            constraints.Description = department.Description;
            constraints.DiscountGroupID = department.DiscountGroupID;
            constraints.ImageFile = department.ImageFile;
            constraints.IsEnabled = department.IsEnabled;
            constraints.MetaDescription = department.GetMetaDescription( culture );
            constraints.MetaKeyword = department.GetMetaKeyword( culture );
            constraints.Name = department.Name;
            constraints.Other1 = department.Other1;
            constraints.Other2 = department.Other2;
            constraints.Other3 = department.Other3;
            constraints.Other4 = department.Other4;
            constraints.Other5 = department.Other5;
            constraints.ParentDepartmentID = department.ParentDepartmentID;
            constraints.ProductListLayoutPath = department.ProductListLayoutPath;
            constraints.RootID = department.RootID;
            constraints.SortOrder = department.SortOrder;
            constraints.UrlName = department.UrlName;
            constraints.IsAnchor = department.IsAnchor;
            constraints.ImageAlt = department.ImageAlt;
            constraints.ImageTitle = department.ImageTitle;
            constraints.IsShowNewArrival = department.IsShowNewArrival;
            constraints.NewArrivalAmount = department.NewArrivalAmount;
            return constraints;
        }

        public DepartmentListResponseMessage ListDepartments( DepartmentListRequestMessage ListMessage )
        {
            DepartmentListResponseMessage responseMessage = new DepartmentListResponseMessage();
            if (WcfSessionPool.GetSession( ListMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter( ListMessage.SearchFilter );
                Culture culture = DataAccessContext.CultureRepository.GetOne( ListMessage.CultureID );
                IList<Department> department_result = DataAccessContext.DepartmentRepository.SearchDepartmentByRootID( culture, "DepartmentID", searchFilter, ListMessage.RootID );
                responseMessage.Departments = new List<DepartmentConstraints>();
                foreach (Department department in department_result)
                {
                    responseMessage.Departments.Add( ConvertDepartmentToConstraints( department, culture ) );
                }
            }
            catch (Exception e)
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get departments from repository";
            }

            return responseMessage;
        }
    }
}
